#======================================================
# arccosine function
#======================================================

# expectation with transformed data
#...................................

tmY_arccos_c = function(mu, sigma, nsample = 1, nterm = 5){
  # In this function we've added the unbiased estimation for alpha and beta 
  # nsample = is the sample size
  
  if (nsample > 1){
    coef = fun_cv_coef(mu, sigma, nsample)
  }else{
    coef = 1
  }
  
  a = - mu/sigma*coef # alpha
  b = pi/sigma - mu/sigma*coef  # beta
  
  spm = sigma/mu*coef  # sigma/mu
  
  # first term \frac{(-1)^n}{(2n+1)!}
  n = 0:nterm
  mup = mu^seq(0,2*nterm, by = 2)

  d1 = (-1)^n
  d1 = d1*mup
  
  d2 = factorial(seq(0, 2*nterm, by = 2))
  
  an = d1/d2
  
  # second term \sum_{k=0}^{2n+1}\binom{2n+1}{k}\xi^{-k}\sigma^{k}I(\alpha,\beta,k)
  k1 = 0:(2*nterm)
  spm_k = spm^k1
  
  # compute I for all the values of k1
  I = c()
  for (i in k1){
    I = c(I, fI(a,b,i))
  }
  
  bt = I*spm_k # the term \xi^{-k}\sigma^{k}I(\alpha,\beta,k) 
  
  bn = c()
  for (i in n){
    c1 = choose(2*i,0:(2*i))
    c2 = c1*bt[1:(2*i+1)]
    bn = c(bn, sum(c2))
  }
  
  return(1/sqrt(2*pi)*sum(an*bn))
}