#======================================================
# arctangent function
#======================================================

# expectation with transformed data
#...................................

tmY_arctangent_c = function(mu, sigma, nsample = 1, nterm = 5){
  # In this function we've added the unbiased estimation for alpha and beta 
  # nsample = is the sample size
  
  if (nsample > 1){
    coef = fun_cv_coef(mu, sigma, nsample)
  }else{
    coef = 1
  }
  
  a = -(pi/4)/sigma - mu/sigma*coef # alpha
  b = (pi/4)/sigma - mu/sigma*coef  # beta
  
  spm = sigma/mu*coef  # sigma/mu
  
  # compute the bernoulli numbers
  
  BNr = function(n){
    BN = rep(1,n+1)
    
    for (i in 1:n){
      vc = choose(i,0:(i-1))
      vc2 = 1/((i+1):2)
      vvc = vc*vc2
      
      BN[i+1] = -sum(vvc*BN[1:i])
    }
    
    return(BN)
  }
  
  BN1 = BNr(2*nterm)
  B2n = BN1[seq(3, 2*nterm+1, by = 2)]
  
  # first term \frac{(-1)^n}{(2n+1)!}
  n = 1:nterm
  mup = mu^seq(1,2*nterm-1, by = 2)

  d1 = (-1)^n
  d1 = d1*4^n
  d1 = d1*(1-4^n)
  d1 = d1*mup
  d1 = d1*B2n
  
  d2 = factorial(seq(2,2*nterm,2))
  
  an = d1/d2
  
  # second term \sum_{k=0}^{2n+1}\binom{2n+1}{k}\xi^{-k}\sigma^{k}I(\alpha,\beta,k)
  k1 = 0:(2*nterm-1)
  spm_k = spm^k1
  
  # compute I for all the values of k1
  I = c()
  for (i in k1){
    I = c(I, fI(a,b,i))
  }
  
  bt = I*spm_k # the term \xi^{-k}\sigma^{k}I(\alpha,\beta,k) 
  
  bn = c()
  for (i in n){
    c1 = choose(2*i-1,0:(2*i-1))
    c2 = c1*bt[1:(2*i)]
    bn = c(bn, sum(c2))
  }
  
  return(1/sqrt(2*pi)*sum(an*bn))
}